==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/uk/compress.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>CompressPlugin</name>
    <message>
        <source>Unsupported compression method</source>
        <translation>Метод стиснення не підтримується</translation>
    </message>
    <message>
        <source>Compression setup failed</source>
        <translation>Не вдалося запустити стиснення</translation>
    </message>
    <message>
        <source>Stream Compression</source>
        <translation>Стиснення потоку</translation>
    </message>
    <message>
        <source>Allows to compress a stream of messages sent and received from the server</source>
        <translation>Дозволяє стискати XML-потоки від і до сервера</translation>
    </message>
</context>
<context>
    <name>Compression</name>
    <message>
        <source>Invalid compression level</source>
        <translation>Неправильний рівень стиснення</translation>
    </message>
    <message>
        <source>invalid or incomplete deflate data</source>
        <translation>Некоректні або неповні стиснені дані</translation>
    </message>
    <message>
        <source>Out of memory for Zlib</source>
        <translation>Не вистачає пам&apos;яті  для Zlib</translation>
    </message>
    <message>
        <source>Zlib version mismatch!</source>
        <translation>Неправильна версія Zlib!</translation>
    </message>
    <message>
        <source>Wrong compression negotiation response</source>
        <translation>Некоректна відповідь під час ініціалізації стиснення</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/uk/compress.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>CompressPlugin</name>
    <message>
        <source>Unsupported compression method</source>
        <translation>Метод стиснення не підтримується</translation>
    </message>
    <message>
        <source>Compression setup failed</source>
        <translation>Не вдалося запустити стиснення</translation>
    </message>
    <message>
        <source>Stream Compression</source>
        <translation>Стиснення потоку</translation>
    </message>
    <message>
        <source>Allows to compress a stream of messages sent and received from the server</source>
        <translation>Дозволяє стискати XML-потоки від і до сервера</translation>
    </message>
    <message>
        <source>Enable data compression transferred between client and server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Compression</name>
    <message>
        <source>Invalid compression level</source>
        <translation>Неправильний рівень стиснення</translation>
    </message>
    <message>
        <source>Out of memory for Zlib</source>
        <translation>Не вистачає пам&apos;яті  для Zlib</translation>
    </message>
    <message>
        <source>Zlib version mismatch!</source>
        <translation>Неправильна версія Zlib!</translation>
    </message>
    <message>
        <source>Wrong compression negotiation response</source>
        <translation>Некоректна відповідь під час ініціалізації стиснення</translation>
    </message>
    <message>
        <source>Invalid or incomplete deflate data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Zlib error, %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
